@@ -4,15 +4,14 @@ Factual API driver
 
 import json
 from functools import partial
-from urllib import urlencode
 
 import requests
 from requests_oauthlib import OAuth1
 
-from query import Resolve, Table, Submit, Insert, Facets, Flag, Geopulse, Geocode, Diffs, Match, Multi, Clear
+from .query import Resolve, Table, Submit, Insert, Facets, Flag, Geopulse, Geocode, Diffs, Match, Multi, Clear, Boost
 
 API_V3_HOST = "http://api.v3.factual.com"
-DRIVER_VERSION_TAG = "factual-python-driver-1.4.2"
+DRIVER_VERSION_TAG = "factual-python-driver-1.5.0"
 
 class Factual(object):
     def __init__(self, key, secret, timeout=None):
@@ -27,8 +26,11 @@ class Factual(object):
     def crosswalk(self):
         return Table(self.api, 't/crosswalk')
 
-    def resolve(self, table, values):
-        return Resolve(self.api, table, {'values': values})
+    def resolve(self, table, values, debug=False):
+        params = {'values': values}
+        if debug:
+            params['debug'] = 'true'
+        return Resolve(self.api, table, params)
 
     def match(self, table, values):
         return Match(self.api, table, {'values': values})
@@ -54,15 +56,15 @@ class Factual(object):
     def flag(self, table, factual_id):
         return Flag(self.api, table, factual_id)
 
+    def boost(self, table, factual_id, q=None):
+        return Boost(self.api, table, factual_id, {'factual_id': factual_id, 'q': q})
+
     def geopulse(self, point={}):
         return Geopulse(self.api, 'geopulse/context', {'geo': point})
 
     def geocode(self, point):
         return Geocode(self.api, 'places/geocode', {'geo': point})
 
-    def monetize(self):
-        return Table(self.api, 'places/monetize')
-
     def diffs(self, table, start, end):
         return Diffs(self.api, 't/' + table + '/diffs', start, end)
 
@@ -102,7 +104,8 @@ class API(object):
 
     def raw_stream_read(self, path, raw_params):
         url = self._build_base_url(path)
-        for line in self._make_request(url, raw_params, partial(self._make_get_request, stream=True)).iter_lines():
+        response = self._make_request(url, raw_params, partial(self._make_get_request, stream=True))
+        for line in response.iter_lines(decode_unicode=True):
             if line:
                 yield line
 
@@ -110,13 +113,16 @@ class API(object):
         url = self._build_base_url(path)
         return self._make_request(url, raw_params, self._make_post_request).text
 
-    def build_url(self, path, params):
-        url = self._build_base_url(path)
-        url += '?' + self._make_query_string(params)
-        return url
+    def build_url(self, path, params, method):
+        return self._prepare_req(path, params, method).url
 
     def build_multi_url(self, query):
-        return '/' + query.path + '?' + self._make_query_string(query.params)
+        return self._prepare_req(query.path, query.params, query.method).path_url
+
+    def _prepare_req(self, path, params, method):
+        url = self._build_base_url(path)
+        req = requests.Request(method, url, params=self._transform_params(params))
+        return req.prepare()
 
     def _build_base_url(self, path):
         return API_V3_HOST + '/' + path
@@ -144,9 +150,6 @@ class API(object):
         headers = {'X-Factual-Lib': DRIVER_VERSION_TAG, 'content-type': 'application/x-www-form-urlencoded'}
         return self.client.post(url, headers=headers, data=params)
 
-    def _make_query_string(self, params):
-        return urlencode([(k,v) for k,v in self._transform_params(params).items()])
-
     def _transform_params(self, params):
         if isinstance(params, str):
             return params
